@@ -3,7 +3,7 @@ import os
 import sys
 
 app_name = 'primaryschool'
-app_version = '0.0.6'
+app_version = '0.0.8'
 app_author = 'larryw3i'
 app_author_email = 'larryw3i@163.com'
 app_maintainer = app_author
@@ -15,25 +15,29 @@ app_contributors = [
     '',
 ]
 
-
+install_prefix = 'python -m pip install '
 requirements = [
     # product
     [  # ('requirement_name','version','project_url','License','license_url')
         (
             'pygame', '', 'https://github.com/pygame/pygame',
-            'LGPL v2', 'https://github.com/pygame/pygame/blob/main/docs/LGPL.txt'
+            'LGPL v2',
+            'https://github.com/pygame/pygame/blob/main/docs/LGPL.txt'
         ),
         (
             'pygame-menu', '', 'https://github.com/ppizarror/pygame-menu',
-            'MIT', 'hhttps://github.com/ppizarror/pygame-menu/blob/master/LICENSE'
+            'MIT',
+            'hhttps://github.com/ppizarror/pygame-menu/blob/master/LICENSE'
         ),
         (
             'xpinyin', '', 'https://github.com/lxneng/xpinyin',
-            'BSD', 'https://github.com/lxneng/xpinyin/blob/master/setup.py#L37'
+            'BSD',
+            'https://github.com/lxneng/xpinyin/blob/master/setup.py#L37'
         ),
         (
             'appdirs', '', 'https://github.com/ActiveState/appdirs',
-            'MIT', 'https://github.com/ActiveState/appdirs/blob/master/LICENSE.txt'
+            'MIT',
+            'https://github.com/ActiveState/appdirs/blob/master/LICENSE.txt'
         ),
     ],
     [
@@ -44,6 +48,11 @@ requirements = [
         (
             'autopep8', '', 'https://github.com/hhatto/autopep8',
             'MIT', 'https://github.com/hhatto/autopep8/blob/master/LICENSE'
+        ),
+        (
+            'nose2', '', 'https://github.com/nose-devs/nose2',
+            'BSD License',
+            'https://github.com/nose-devs/nose2/blob/main/setup.py#L57'
         )
     ]
 ]
@@ -56,6 +65,11 @@ def get_requirements_product():
     return install_requires
 
 
+def install_requirements_product():
+    requirements_product = get_requirements_product()
+    os.system(install_prefix + requirements_product)
+
+
 def get_requirements_dev():
     install_requires = ''
     for r in requirements:
@@ -64,9 +78,19 @@ def get_requirements_dev():
     return install_requires
 
 
+def install_requirements_dev():
+    requirements_dev = get_requirements_dev()
+    os.system(install_prefix + requirements_dev)
+
+
 def get_requirements_dev_u():
-    install_requires = ''
+    install_requires = '-U'
     for r in requirements:
         for _r in r:
             install_requires += ' ' + _r[0]
     return install_requires
+
+
+def install_requirements_dev_u():
+    requirements_dev_u = get_requirements_dev_u()
+    os.system(install_prefix + requirements_dev_u)
